﻿# SoundBoard.AHK

A lightweight, fully customizable soundboard built with AutoHotkey.  
Allows users to assign sound files to hotkeys dynamically through an `.ini` configuration file. No recompiling needed to change keys or sounds since it's handled on the seperate file.

---

## Features
- **Custom Hotkeys**: Bind any key you want with control (`Ctrl`) or alt (`Alt`) modifiers (by default).
- **Fully Configurable**: All key and modifier settings are stored in a simple `.ini` file.
- **Save and Reload Settings**: Save hotkey and sound assignments anytime without restarting the script.
- **Minimal & Fast**: No external libraries required, fully standalone.

---

## How It Works

1. All hotkey mappings are loaded from a `.ini` file (`save.ini` by default).
2. Modifier keys (e.g., Control, Alt) can also be customized through the ini.
3. Two types of actions:
   - **Browse**: Press `Control + [Your Key]` to select a sound file (BY DEFAULT).
   - **Play**: Press `Alt + [Your Key]` to play the assigned sound (BY DEFAULT).

The script automatically handles key registration at runtime.

---

## Default Controls

| Action       | Key Combination        | Description             |
|--------------|-------------------------|--------------------------|
| Browse Sound | `Ctrl + [Assigned Key]`  | Choose a sound file      |
| Play Sound   | `Alt + [Assigned Key]`   | Play assigned sound      |
| Save Mapping | `Ctrl + Alt + Shift +s`         | Save all key mappings    |
| Exit Script  | `Ctrl + Win + Alt + X`   | Exit the soundboard      |

All keys are configurable via `save.ini`.

---

## Example `save.ini`

```ini
[Settings]
ControllerModifier=^
SoundModifier=!

[GeneralHotkeys]
SaveKey=^!+s
ExitKey=^#!x

[h1]
key=F1
path=C:\Sounds\sound1.wav

[h2]
key=F2
path=C:\Sounds\sound2.wav

; Add more sections like [h3], [h4], etc.
````

---

## How To Use

1. Install [AutoHotkey v1.1](https://www.autohotkey.com/) (classic) if you don't have it.
2. Clone this repository or download the `.ahk` script.
3. Edit `save.ini` according to your preferred hotkeys and sound files.
4. Run the script (`soundboard.ahk`).
5. Enjoy your custom soundboard!

---

## ⚙Requirements

* Windows OS
* AutoHotkey v1.1 (or newer)

---

## License

This project is licensed under the [MIT License](MIT-LICENSE.txt).

## Support This Project

If you find this project helpful, you can support my work by donating via PayPal:  
👉 [![Donate](https://img.shields.io/badge/Donate-PayPal-blue.svg)](https://www.paypal.me/rafli23115)

Thank you for your support!

---

> Crafted with 💡 and code by **TechLabs.**
**Leaping over limits, one project at a time. ♾**
